from django.urls import path, include
from rest_framework.routers import DefaultRouter
from .views import (
    KnowledgeBaseViewSet,
    PermissionViewSet,
    NotificationViewSet,
    verify_token,
    user_list,
    user_detail,
    user_update,
    user_delete,
    change_password,
    RegisterView,
    LoginView,
    LogoutView,
    ChatHistoryViewSet
)

# 创建路由器
router = DefaultRouter()

# 注册视图集
router.register(r'knowledge-bases', KnowledgeBaseViewSet, basename='knowledge-base')
router.register(r'permissions', PermissionViewSet, basename='permission')
router.register(r'notifications', NotificationViewSet, basename='notification')
router.register(r'chat-history', ChatHistoryViewSet, basename='chat-history')

# URL patterns
urlpatterns = [
    # API 路由
    path('', include(router.urls)),
    
    # 用户认证相关
    path('auth/register/', RegisterView.as_view(), name='register'),
    path('auth/login/', LoginView.as_view(), name='login'),
    path('auth/logout/', LogoutView.as_view(), name='logout'),
    path('auth/verify-token/', verify_token, name='verify-token'),
    path('auth/change-password/', change_password, name='change-password'),
    
    # 用户管理相关
    path('users/', user_list, name='user-list'),
    path('users/<str:pk>/', user_detail, name='user-detail'),
    path('users/<str:pk>/update/', user_update, name='user-update'),
    path('users/<str:pk>/delete/', user_delete, name='user-delete'),
]
